#
# spec file for package python3-gevent
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-gevent
Version:        1.1.2
Release:        3.11
Summary:        Python network library that uses greenlet and libevent
License:        MIT
Group:          Development/Languages/Python
Url:            http://www.gevent.org/
Source:         https://files.pythonhosted.org/packages/source/g/gevent/gevent-%{version}.tar.gz
BuildRequires:  libcares-devel
BuildRequires:  libev-devel
#BuildRequires:  python-Sphinx
BuildRequires:  python3-devel
BuildRequires:  python3-greenlet
BuildRequires:  python3-nose
Requires:       python3-greenlet
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Gevent is a Python networking library that uses greenlet to provide synchronous
API on top of a libevent event loop. Features include:

  * Fast event loop based on libevent.
  * Lightweight execution units based on greenlet.
  * Familiar API that re-uses concepts from the Python standard library.
  * Cooperative sockets with ssl support.
  * DNS queries performed through libevent-dns.
  * Ability to use standard library and 3rd party modules written for standard
    blocking sockets
  * Fast WSGI server based on libevent-http.

gevent is inspired by eventlet but features more consistent API, simpler
implementation and better performance. Read why others use gevent and check
out the list of the open source projects based on gevent.

%prep
%setup -q -n gevent-%{version}
# Remove bundled libraries
rm -rf c-ares libev

%build
CFLAGS="%{optflags} -fno-strict-aliasing" python3 setup.py build
#cd doc && make html && rm _build/html/.buildinfo # Build HTML documentation

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
nosetests

%files
%defattr(-,root,root,-)
%doc AUTHORS changelog.rst LICENSE* README.rst TODO examples
#%%doc doc/_build/html
%{python3_sitearch}/*

%changelog
* Thu Jul 21 2016 arun@gmx.de
- update to version 1.1.2:
  * Python 2: sendall on a non-blocking socket could spuriously fail
    with a timeout.
  * If sys.stderr has been monkey-patched (not recommended),
    exceptions that the hub reports aren't lost and can still be
    caught. Reported in :issue:`825` by Jelle Smet.
  * :class:`selectors.SelectSelector` is properly monkey-patched
    regardless of the order of imports. Reported in :issue:`835` by
    Przemysław Węgrzyn.
  * Python 2: reload(site) no longer fails with a TypeError if gevent
    has been imported. Reported in :issue:`805` by Jake Hilton.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * changed to https for source url
  * updated source url to files.pythonhosted.org
* Sun Apr 10 2016 arun@gmx.de
- update to version 1.1.1:
  * Nested callbacks that set and clear an Event no longer cause wait
    to return prematurely. Reported in :issue:`771` by Sergey
    Vasilyev.
  * Fix build on Solaris 10. Reported in :issue:`777` by wiggin15.
  * The ref parameter to :func:`gevent.os.fork_and_watch` was being
    ignored.
  * Python 3: :class:`gevent.queue.Channel` is now correctly iterable,
    instead of raising a :exc:`TypeError`.
  * Python 3: Add support for :meth:`socket.socket.sendmsg`,
    :meth:`socket.socket.recvmsg` and
    :meth:`socket.socket.recvmsg_into` on platforms where they are
    defined. Initial :pr:`773` by Jakub Klama.
* Thu Mar 10 2016 toddrme2178@gmail.com
- Update to 1.1.0 (final):
  * See changelog.rst for detailed informations
* Fri Jan 29 2016 toddrme2178@gmail.com
- Initial python3 version.
* Fri Jan 29 2016 tchvatal@suse.com
- Update to 1.1rc3:
  * See changelog.rst for detailed informations
* Wed Jul  1 2015 tchvatal@suse.com
- Bump once more to 1.1a1:
  * See changelog.rst for detailed informations
  * The py2.7 compat in 1.0.2 behaves weirdly on openSUSE,
    this release seems way nicer on that front
* Tue Jun 30 2015 tchvatal@suse.com
- Version bump to 1.0.2:
  - Fix LifoQueue.peek() to return correct element. PR #456. Patch by Christine
    Spang.
  - Upgrade to libev 4.19
  - Remove SSL3 entirely as default TLS protocol
  - Import socket on Windows (closes #459)
  - Fix C90 syntax error (PR #449)
  - Add compatibility with Python 2.7.9's SSL changes. Issue #477.
* Tue Nov 18 2014 toddrme2178@gmail.com
- Update to 1.0.1
  - Upgrade libev to 4.15. This fixes #361: installation on armv5.
  - Better support for win64. Patch by Alexey Borzenkov.
  - Fix #423: Pool's imap/imap_unordered could hang forever. Based on patch and test by Jianfei Wang.
  - Enable libev's check watchers.
  - Add dummy Event._reset_internal_locks() method. Only relevant if patch_all(Event=True) is enabled (non-default).
  - Backport new testrunner.py from master branch.
- Removed upstream included libev.patch
* Thu Jun 12 2014 schwab@suse.de
- libev.patch: fix syntax error in preprocessor conditional
* Sun Dec 15 2013 p.drouand@gmail.com
- Update to version 1.0
  + pywsgi: Pass copy of error list instead of direct reference
  + Ignore the autogenerated doc/gevent.*.rst files.
  + Fix cythonpp.py on Windows.
  + Remove gevent.run (use gevent.wait).
* Fri Oct 26 2012 douglarek@outlook.com
- Update to version 0.13.8:
  * Fixed issue #80: gevent.httplib failed with RequestFailed errors because timeout was reset to 1s. Patch by Tomasz Prus.
  * core: fix compilation with the latest Cython: remove emit_ifdef/emit_else/emit_endif.
  * Fixed issue #132: gevent.socket.gethostbyname(<unicode>) now does ascii encoding and uses gevent's resolver rather than
    calling built-in resolver. Patch by Alexey Borzenkov.
* Mon Jun 25 2012 saschpe@suse.de
- Update to version 0.13.7:
  + Fixed #94: fallback to buffer if memoryview fails in _get_memory on
    python 2.7.
  + Fixed #103: ``Queue(None).full()`` returns ``False`` now (previously
    it returned ``True``).
  + Fixed #112: threading._sleep is not patched.
  + Fixed #115: _dummy gets unexpected Timeout arg.
* Tue Mar 27 2012 saschpe@suse.de
- Run testsuite
- Require python-greenlet
- Simplify macro usage
* Fri Nov 18 2011 saschpe@suse.de
- Cython should not be needed, gevent is build as a binary module
* Tue Jul 19 2011 saschpe@suse.de
- Initial version
